@@ -81,8 +81,8 @@ copy_dir_rec (const char *src, const char *dst, int preserve_id,
 	    {
 	      if (mknod (dstfile, st.st_mode & ~07777, st.st_rdev) != 0)
 		{
-		  fprintf (stderr, _("Cannot create special file `%s': %s\n"),
-			   dstfile, strerror (errno));
+		  fprintf (stderr, _("Can't create `%s': %m\n"),
+			   dstfile);
 		  retval = 1;
 		}
 	      else if (chown (dstfile,
@@ -117,7 +117,7 @@ copy_dir_rec (const char *src, const char *dst, int preserve_id,
 			     preserve_id ? st.st_gid : gid) != 0 ||
 		      chmod (dstfile, st.st_mode & 07777) != 0)
 		    {
-		      fprintf (stderr, _("Cannot set permissions for `%s': %s\n"),
+		      fprintf (stderr, _("Cannot change permissions for `%s': %s\n"),
 			       dstfile, strerror (errno));
 		      /* An error occured, remove the new subtree.  */
 		      remove_dir_rec (dstfile);
@@ -150,7 +150,8 @@ copy_dir_rec (const char *src, const char *dst, int preserve_id,
 				   preserve_id ? st.st_uid : uid,
 				   preserve_id ? st.st_gid : gid) != 0)
 		    {
-		      fprintf (stderr, _("Cannot set permissions for `%s': %s\n"),
+		      fprintf (stderr,
+                               _("Cannot change owner/group for `%s': %s\n"),
 			       dstfile, strerror (errno));
 		      unlink (dstfile);
 		      retval = 1;
@@ -201,7 +202,7 @@ copy_dir_rec (const char *src, const char *dst, int preserve_id,
 			     preserve_id ? st.st_gid : gid) != 0 ||
 		      chmod (dstfile, st.st_mode & 07777))
 		    {
-		      fprintf (stderr, _("Cannot set permissions for `%s': %s\n"),
+		      fprintf (stderr, _("Cannot change permissions for `%s': %s\n"),
 			       dstfile, strerror (errno));
 		      unlink (dstfile);
 		      retval = 1;
