@@ -338,13 +338,13 @@ write_group_data (group_t *data, int is_locked)
 
 	  if ((oldgf = fopen (group_orig, "r")) == NULL)
 	    {
-	      fprintf (stderr, _("Can't open %s: %m\n"), group_orig);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), group_orig);
 	      retval = -1;
 	      goto error_group;
 	    }
           if (fstat (fileno (oldgf), &group_stat) < 0)
             {
-	      fprintf (stderr, _("Can't stat %s: %m\n"), group_orig);
+	      fprintf (stderr, _("Can't stat `%s': %m\n"), group_orig);
               fclose (oldgf);
 	      retval = -1;
               goto error_group;
@@ -373,7 +373,7 @@ write_group_data (group_t *data, int is_locked)
 #endif
 	  if (newgf_fd == -1)
 	    {
-	      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+	      fprintf (stderr, _("Can't create `%s': %m\n"),
 		       group_orig);
 	      fclose (oldgf);
 	      retval = -1;
@@ -382,7 +382,7 @@ write_group_data (group_t *data, int is_locked)
           if (fchmod (newgf_fd, group_stat.st_mode) < 0)
             {
               fprintf (stderr,
-                       _("Cannot change mode for `%s': %s\n"),
+                       _("Cannot change permissions for `%s': %s\n"),
                        group_tmp, strerror (errno));
               fclose (oldgf);
               close (newgf_fd);
@@ -413,7 +413,7 @@ write_group_data (group_t *data, int is_locked)
 	  newgf = fdopen (newgf_fd, "w+");
 	  if (newgf == NULL)
 	    {
-	      fprintf (stderr, _("Can't open %s: %m\n"), group_tmp);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), group_tmp);
 	      fclose (oldgf);
 	      close (newgf_fd);
 	      unlink (group_tmp);
@@ -439,7 +439,8 @@ write_group_data (group_t *data, int is_locked)
 		      if (putgrent (&data->gr, newgf) < 0)
 			{
 			  fprintf (stderr,
-				   _("Error while writing temporary group file: %m\n"));
+				   _("Error while writing `%s': %m\n"),
+                                   group_tmp);
 			  fclose (oldgf);
 			  fclose (newgf);
 			  retval = -1;
@@ -481,7 +482,8 @@ write_group_data (group_t *data, int is_locked)
 	      if (putgrent (gr, newgf) < 0)
 		{
 		  fprintf (stderr,
-			   _("Error while writing temporary group file: %m\n"));
+			   _("Error while writing `%s': %m\n"),
+                           group_tmp);
 		  fclose (oldgf);
 		  fclose (newgf);
 		  retval = -1;
@@ -494,7 +496,8 @@ write_group_data (group_t *data, int is_locked)
 	      if (putgrent (&data->gr, newgf) < 0)
 		{
 		  fprintf (stderr,
-			   _("Error while writing temporary group file: %m\n"));
+			   _("Error while writing `%s': %m\n"),
+                           group_tmp);
 		  fclose (oldgf);
 		  fclose (newgf);
 		  retval = -1;
@@ -512,7 +515,7 @@ write_group_data (group_t *data, int is_locked)
 	  if (fclose (oldgf) != 0)
 	    {
 	      fprintf (stderr,
-		       _("Error while closing old group file: %m\n"));
+		       _("Error while closing `%s': %m\n"), group_orig);
 	      fclose (newgf);
 	      retval = -1;
 	      goto error_group;
@@ -520,18 +523,19 @@ write_group_data (group_t *data, int is_locked)
 	  if (fclose (newgf) != 0)
 	    {
 	      fprintf (stderr,
-		       _("Error while closing temporary group file: %m\n"));
+		       _("Error while closing `%s': %m\n"), group_tmp);
 	      retval = -1;
 	      goto error_group;
 	    }
 	  unlink (group_old);
 	  if (link (group_orig, group_old) < 0)
 	    fprintf (stderr,
-                     _("Warning: cannot create backup of group file: %m\n"));
+                     _("Warning: cannot create backup file `%s': %m\n"),
+		     group_old);
 	  if (rename (group_tmp, group_orig) < 0)
 	    {
 	      fprintf (stderr,
-                       _("Error while renaming temporary group file: %m\n"));
+                       _("Error while renaming `%s': %m\n"), group_tmp);
               retval = -1;
               goto error_group;
             }
