@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,11 @@
 
 #include <grp.h>
 #include <public.h>
+#include <sys/cdefs.h>
+
+#ifndef __attribute_warn_unused_result__
+#define __attribute_warn_unused_result__
+#endif
 
 struct group_t {
   todo_t todo;
@@ -40,6 +45,6 @@ typedef struct group_t group_t;
 extern void free_group_t (group_t *data);
 extern group_t *find_group_data (const char *group, gid_t gid,
 				 const char *use_service);
-extern int write_group_data (group_t *data, int is_locked);
+extern int write_group_data (group_t *data, int is_locked) __attribute_warn_unused_result__;
 
 #endif /* __GROUP_H__ */
