@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <limits.h>
+#include <assert.h>
 
 #include "logindefs.h"
 
@@ -33,6 +34,7 @@ struct item {
   char *name;         /* name of the option.  */
   char *value;        /* value of the option.  */
   struct item *next;  /* pointer to next option.  */
+  char *path;         /* name of config file for this option.  */
 };
 
 static struct item *list = NULL;
@@ -47,6 +49,7 @@ free_getlogindefs_data (void)
     {
       struct item *tmp;
       tmp = ptr->next;
+      free (ptr->path);
       free (ptr->name);
       free (ptr->value);
       free (ptr);
@@ -58,7 +61,7 @@ free_getlogindefs_data (void)
 
 /* Add a new entry to the list.  */
 static void
-store (const char *name, const char *value)
+store (const char *name, const char *value, const char *path)
 {
   struct item *new = malloc (sizeof (struct item));
 
@@ -68,8 +71,11 @@ store (const char *name, const char *value)
   if (name == NULL)
     abort ();
 
+  assert (name);
   new->name = strdup (name);
   new->value = strdup (value?:"");
+  assert (path);
+  new->path = strdup (path);
   new->next = list;
   list = new;
 }
@@ -91,7 +97,27 @@ search (const char *name)
   return NULL;
 }
 
-/* Load the login.defs file (/etc/login.defs)  */
+/* search a special entry in the list and return the filename
+   from where we got it.  */
+static const char *
+search_config (const char *name)
+{
+  struct item *ptr;
+
+  ptr = list;
+  while (ptr != NULL)
+    {
+      if (strcasecmp (name, ptr->name) == 0)
+	return ptr->path;
+      ptr = ptr->next;
+    }
+
+  /* Should not happen, we found the entry already.  */
+  assert (NULL);
+  return NULL;
+}
+
+/* Load the config file  */
 static void
 load_defaults_internal (const char *filename)
 {
@@ -146,7 +172,7 @@ load_defaults_internal (const char *filename)
 	while (isspace ((int)*cp) || *cp == '=')
 	  ++cp;
 
-      store (tmp, cp);
+      store (tmp, cp, filename);
     }
   fclose (fp);
 
@@ -197,8 +223,8 @@ getlogindefs_num (const char *name, long dflt)
       ((retval == LONG_MAX || retval == LONG_MIN) && errno == ERANGE))
     {
       fprintf (stderr,
-	       "login.defs: %s contains invalid numerical value: %s!\n",
-	       name, val);
+	       "%s: %s contains invalid numerical value: %s!\n",
+	       search_config (name), name, val);
       retval = dflt;
     }
   return retval;
@@ -223,8 +249,8 @@ getlogindefs_unum (const char *name, unsigned long dflt)
   if (*cp != '\0' || (retval == ULONG_MAX && errno == ERANGE))
     {
       fprintf (stderr,
-	       "login.defs: %s contains invalid numerical value: %s!\n",
-	       name, val);
+	       "%s: %s contains invalid numerical value: %s!\n",
+	       search_config (name), name, val);
       retval = dflt;
     }
   return retval;
