@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2004 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,8 @@
 
 #include "public.h"
 
-/* convert a string to a time_t value.  */
+/* convert a string to a time_t value and return it as number
+   of days since 1.1.1970.  */
 long int
 str2date (const char *str)
 {
@@ -45,4 +46,3 @@ str2date (const char *str)
 
   return (result + (DAY/2)) / DAY;
 }
-
