@@ -444,13 +444,13 @@ write_user_data (user_t *data, int is_locked)
 
 	  if ((oldpf = fopen (passwd_orig, "r")) == NULL)
 	    {
-	      fprintf (stderr, _("Can't open %s: %m\n"), passwd_orig);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), passwd_orig);
 	      retval = -1;
 	      goto error_passwd;
 	    }
           if (fstat (fileno (oldpf), &passwd_stat) < 0)
             {
-	      fprintf (stderr, _("Can't stat %s: %m\n"), passwd_orig);
+	      fprintf (stderr, _("Can't stat `%s': %m\n"), passwd_orig);
               fclose (oldpf);
 	      retval = -1;
               goto error_passwd;
@@ -479,7 +479,7 @@ write_user_data (user_t *data, int is_locked)
 #endif
 	  if (newpf_fd == -1)
 	    {
-	      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+	      fprintf (stderr, _("Can't create `%s': %m\n"),
 		       passwd_orig);
 	      fclose (oldpf);
 	      retval = -1;
@@ -488,7 +488,7 @@ write_user_data (user_t *data, int is_locked)
           if (fchmod (newpf_fd, passwd_stat.st_mode) < 0)
 	    {
 	      fprintf (stderr,
-		       _("Cannot change mode for `%s': %s\n"),
+		       _("Cannot change permissions for `%s': %s\n"),
 		       passwd_tmp, strerror (errno));
 	      fclose (oldpf);
 	      close (newpf_fd);
@@ -518,7 +518,7 @@ write_user_data (user_t *data, int is_locked)
 	  newpf = fdopen (newpf_fd, "w+");
 	  if (newpf == NULL)
 	    {
-	      fprintf (stderr, _("Can't open %s: %m\n"), passwd_tmp);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), passwd_tmp);
 	      fclose (oldpf);
 	      close (newpf_fd);
 	      unlink (passwd_tmp);
@@ -544,7 +544,8 @@ write_user_data (user_t *data, int is_locked)
 		      if (putpwent (&data->pw, newpf) < 0)
 			{
 			  fprintf (stderr,
-				   _("Error while writing temporary password file: %m\n"));
+				   _("Error while writing `%s': %m\n"),
+				   passwd_tmp);
 			  fclose (oldpf);
 			  fclose (newpf);
 			  retval = -1;
@@ -594,7 +595,7 @@ write_user_data (user_t *data, int is_locked)
 	      if (putpwent (pw, newpf) < 0)
 		{
 		  fprintf (stderr,
-			   _("Error while writing temporary password file: %m\n"));
+			   _("Error while writing `%s': %m\n"), passwd_tmp);
 		  fclose (oldpf);
 		  fclose (newpf);
 		  retval = -1;
@@ -608,7 +609,7 @@ write_user_data (user_t *data, int is_locked)
 	      if (putpwent (&data->pw, newpf) < 0)
 		{
 		  fprintf (stderr,
-			   _("Error while writing temporary password file: %m\n"));
+			   _("Error while writing `%s': %m\n"), passwd_tmp);
 		  fclose (oldpf);
 		  fclose (newpf);
 		  retval = -1;
@@ -626,7 +627,7 @@ write_user_data (user_t *data, int is_locked)
 	  if (fclose (oldpf) != 0)
 	    {
 	      fprintf (stderr,
-		       _("Error while closing old password file: %m\n"));
+		       _("Error while closing `%s': %m\n"), passwd_orig);
 	      fclose (newpf);
 	      retval = -1;
 	      goto error_passwd;
@@ -634,18 +635,19 @@ write_user_data (user_t *data, int is_locked)
 	  if (fclose (newpf) != 0)
 	    {
 	      fprintf (stderr,
-		       _("Error while closing temporary password file: %m\n"));
+		       _("Error while closing `%s': %m\n"), passwd_tmp);
 	      retval = -1;
 	      goto error_passwd;
 	    }
 	  unlink (passwd_old);
 	  if (link (passwd_orig, passwd_old) < 0)
 	    fprintf (stderr,
-		     _("Warning: cannot create backup of passwd file: %m\n"));
+		     _("Warning: cannot create backup file `%s': %m\n"),
+                     passwd_old);
 	  if (rename (passwd_tmp, passwd_orig) < 0)
 	    {
 	      fprintf (stderr,
-		       _("Error while renaming temporary password file: %m\n"));
+		       _("Error while renaming `%s': %m\n"), passwd_tmp);
 	      retval = -1;
 	      goto error_passwd;
 	    }
@@ -683,13 +685,13 @@ write_user_data (user_t *data, int is_locked)
              friends here, because they go through the YP maps, too. */
           if ((oldpf = fopen (shadow_orig, "r")) == NULL)
             {
-	      fprintf (stderr, _("Can't open %s: %m\n"), shadow_orig);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), shadow_orig);
 	      retval = -1;
               goto error_shadow;
             }
           if (fstat (fileno (oldpf), &shadow_stat) < 0)
             {
-	      fprintf (stderr, _("Can't stat %s: %m\n"), shadow_orig);
+	      fprintf (stderr, _("Can't stat `%s': %m\n"), shadow_orig);
               fclose (oldpf);
 	      retval = -1;
               goto error_shadow;
@@ -718,7 +720,7 @@ write_user_data (user_t *data, int is_locked)
 #endif
           if (newpf_fd == -1)
             {
-	      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+	      fprintf (stderr, _("Can't create `%s': %m\n"),
 		       shadow_orig);
               fclose (oldpf);
 	      retval = -1;
@@ -727,7 +729,7 @@ write_user_data (user_t *data, int is_locked)
           if (fchmod (newpf_fd, shadow_stat.st_mode) < 0)
 	    {
 	      fprintf (stderr,
-		       _("Cannot change mode for `%s': %s\n"),
+		       _("Cannot change permissions for `%s': %s\n"),
 		       shadow_tmp, strerror (errno));
 	      fclose (oldpf);
 	      close (newpf_fd);
@@ -757,7 +759,7 @@ write_user_data (user_t *data, int is_locked)
           newpf = fdopen (newpf_fd, "w+");
           if (newpf == NULL)
             {
-	      fprintf (stderr, _("Can't open %s: %m\n"), shadow_tmp);
+	      fprintf (stderr, _("Can't open `%s': %m\n"), shadow_tmp);
               fclose (oldpf);
               close (newpf_fd);
 	      unlink (shadow_tmp);
@@ -782,8 +784,8 @@ write_user_data (user_t *data, int is_locked)
 		      /* write the passwd entry to tmp file */
 		      if (putspent (&data->sp, newpf) < 0)
 			{
-			  fprintf (stderr, _("\
-Error while writing temporary shadow file: %m\n"));
+			  fprintf (stderr, _("Error while writing `%s': %m\n"),
+                                  shadow_tmp);
 			  fclose (oldpf);
 			  fclose (newpf);
 			  retval = -1;
@@ -837,8 +839,8 @@ Error while writing temporary shadow file: %m\n"));
 		  /* write the passwd entry to tmp file */
 		  if (putspent (sp, newpf) < 0)
 		    {
-		      fprintf (stderr, _("\
-Error while writing temporary shadow file: %m\n"));
+		      fprintf (stderr, _(" Error while writing `%s': %m\n"),
+                               shadow_tmp);
 		      fclose (oldpf);
 		      fclose (newpf);
 		      retval = -1;
@@ -852,8 +854,8 @@ Error while writing temporary shadow file: %m\n"));
 	      /* Add the new user at the end. */
 	      if (putspent (&data->sp, newpf) < 0)
 		{
-		  fprintf (stderr, _("\
-Error while writing temporary shadow file: %m\n"));
+		  fprintf (stderr, _("Error while writing `%s': %m\n"),
+			   shadow_tmp);
 		  fclose (oldpf);
 		  fclose (newpf);
 		  retval = -1;
@@ -862,25 +864,27 @@ Error while writing temporary shadow file: %m\n"));
 	    }
 	  if (fclose (oldpf) != 0)
 	    {
-	      fprintf (stderr, _("Error while closing old shadow file: %m\n"));
+	      fprintf (stderr, _("Error while closing `%s': %m\n"),
+		       shadow_orig);
 	      fclose (newpf);
 	      retval = -1;
 	      goto error_shadow;
 	    }
 	  if (fclose (newpf) != 0)
 	    {
-	      fprintf (stderr, _("\
-Error while closing temporary shadow file: %m\n"));
+	      fprintf (stderr, _("Error while closing `%s': %m\n"),
+		       shadow_tmp);
 	      retval = -1;
 	      goto error_shadow;
 	    }
           unlink (shadow_old);
 	  if (link (shadow_orig, shadow_old) < 0)
-	    fprintf (stderr, _("Warning: cannot create backup of shadow file: %m\n"));
+	    fprintf (stderr, _("Warning: cannot create backup file `%s': %m\n"),
+		     shadow_old);
           if (rename (shadow_tmp, shadow_orig) < 0)
 	    {
-	      fprintf (stderr,
-		       _("Error while renaming temporary shadow file: %m\n"));
+	      fprintf (stderr, _("Error while renaming `%s': %m\n"),
+		       shadow_tmp);
 	      retval = -1;
 	      goto error_shadow;
 	    }
