@@ -80,12 +80,12 @@ print_help (const char *program)
   fputs (_("  -P path        Search passwd and shadow file in \"path\"\n"),
 	 stdout);
 
-  fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("  -q, --quiet    Don't be verbose\n"), stdout);
   fputs (_("      --help     Give this help list\n"), stdout);
   fputs (_("  -u, --usage    Give a short usage message\n"), stdout);
   fputs (_("  -v, --version  Print program version\n"), stdout);
-  fputs (_("Valid services for -r are: files, nis, nisplus, ldap\n"), stdout);
+  fputs (_("Valid services are: files, nis, nisplus, ldap\n"), stdout);
 }
 
 /* Print the time in a human readable format.  */
@@ -288,14 +288,14 @@ main (int argc, char *argv[])
 #endif
 	{"quiet",      no_argument,       NULL, 'q' },
 	{"path",       required_argument, NULL, 'P' },
-	{"service",    required_argument, NULL, 'r' },
 	{"version",    no_argument,       NULL, 'v' },
 	{"usage",      no_argument,       NULL, 'u' },
+	{"service",    required_argument, NULL, '\254' },
 	{"help",       no_argument,       NULL, '\255' },
 	{NULL,         0,                 NULL, '\0'}
       };
 
-      c = getopt_long (argc, argv, "lm:M:d:D:I:E:W:P:r:vuq",
+      c = getopt_long (argc, argv, "lm:M:d:D:I:E:W:P:vuq",
 		       long_options, &option_index);
       if (c == (-1))
         break;
@@ -344,7 +344,10 @@ main (int argc, char *argv[])
 	  else
 	    files_etc_dir = strdup (optarg);
 	  break;
-	case 'r':
+	case 'q':
+	  silent = 1;
+	  break;
+	case '\254':
 	  if (use_service != NULL)
 	    {
 	      print_usage (stderr, program);
@@ -365,14 +368,11 @@ main (int argc, char *argv[])
 #endif
 	  else
 	    {
-	      fprintf (stderr, _("Service `%s' not supported\n"), optarg);
+	      fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
 	      print_usage (stderr, program);
 	      return E_BAD_ARG;
 	    }
 	  break;
-	case 'q':
-	  silent = 1;
-	  break;
         case '\255':
           print_help (program);
           return 0;
@@ -393,7 +393,7 @@ main (int argc, char *argv[])
 
   if (argc > 1)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
