@@ -94,7 +94,7 @@ print_help_shadow (const char *program)
   fputs (_("  -v, --version  Print program version\n"), stdout);
 
   if (strcmp(program, "chfn") == 0)
-    fputs (_("Valid services for -r are: files, nis, nisplus, ldap\n"),
+    fputs (_("Valid services are: files, nis, nisplus, ldap\n"),
 	   stdout);
 }
 
@@ -123,14 +123,14 @@ print_help_util (const char *program)
   fputs (_("  -h home-phone  Change your home phone number\n"), stdout);
   fputs (_("  -m other       Change the undefined portions of the GECOS field\n"), stdout);
   if (strcmp(program, "chfn") == 0)
-    fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+    fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("  -q, --quiet    Don't be verbose\n"), stdout);
   fputs (_("      --help     Give this help list\n"), stdout);
   fputs (_("  -u, --usage    Give a short usage message\n"), stdout);
   fputs (_("  -v, --version  Print program version\n"), stdout);
 
   if (strcmp(program, "chfn") == 0)
-    fputs (_("Valid services for -r are: files, nis, nisplus, ldap\n"),
+    fputs (_("Valid services are: files, nis, nisplus, ldap\n"),
 	   stdout);
 }
 
@@ -308,14 +308,14 @@ main (int argc, char *argv[])
     {"phone",       required_argument, NULL, 'p' },
     {"home-phone",  required_argument, NULL, 'h' },
     {"other",       required_argument, NULL, 'm' },
-    {"service",     required_argument, NULL, 'r' },
     {"quiet",       no_argument,       NULL, 'q' },
     {"version",     no_argument,       NULL, 'v' },
     {"usage",       no_argument,       NULL, 'u' },
+    {"service",     required_argument, NULL, '\254' },
     {"help",        no_argument,       NULL, '\255' },
     {NULL,          0,                 NULL, '\0'}
   };
-  static char *optstring_util = "D:P:f:o:p:h:r:m:qvu";
+  static char *optstring_util = "D:P:f:o:p:h:m:qvu";
   struct option *long_options;
   char *optstring;
   char *envstr;
@@ -382,7 +382,6 @@ main (int argc, char *argv[])
 	  interactive = 0;
 	  break;
 	case 'r':
-	case '\254':
 	case 'o':
 	case 'm':
 	  /* This four have all a different meaning, depending on
@@ -412,40 +411,38 @@ main (int argc, char *argv[])
 	      new.roomno = locale_to_utf8 (optarg);
 	      interactive = 0;
 	    }
+	  break;
+	case '\254':
+	  if (use_service != NULL)
+	    {
+	      if (shadow_chfn)
+		print_usage_shadow (stderr, program);
+	      else
+		print_usage_util (stderr, program);
+	      return 1;
+	    }
+
+	  if (strcasecmp (optarg, "yp") == 0 ||
+	      strcasecmp (optarg, "nis") == 0)
+	    use_service = "nis";
+	  else if (strcasecmp (optarg, "nis+") == 0 ||
+		   strcasecmp (optarg, "nisplus") == 0)
+	    use_service = "nisplus";
+	  else if (strcasecmp (optarg, "files") == 0)
+	    use_service = "files";
+#ifdef USE_LDAP
+	  else if (strcasecmp (optarg, "ldap") == 0)
+	    use_service = "ldap";
+#endif
 	  else
 	    {
-	      /* shadow chfn --service is identical to -r.  */
-	      if (use_service != NULL)
-		{
-		  if (shadow_chfn)
-		    print_usage_shadow (stderr, program);
-		  else
-		    print_usage_util (stderr, program);
-		  return 1;
-		}
-
-	      if (strcasecmp (optarg, "yp") == 0 ||
-		  strcasecmp (optarg, "nis") == 0)
-		use_service = "nis";
-	      else if (strcasecmp (optarg, "nis+") == 0 ||
-		       strcasecmp (optarg, "nisplus") == 0)
-		use_service = "nisplus";
-	      else if (strcasecmp (optarg, "files") == 0)
-		use_service = "files";
-#ifdef USE_LDAP
-	      else if (strcasecmp (optarg, "ldap") == 0)
-		use_service = "ldap";
-#endif
+	      fprintf (stderr,
+		       _("Service `%s' not supported.\n"), optarg);
+	      if (shadow_chfn)
+		print_usage_shadow (stderr, program);
 	      else
-		{
-		  fprintf (stderr,
-			   _("Service `%s' not supported.\n"), optarg);
-		  if (shadow_chfn)
-		    print_usage_shadow (stderr, program);
-		  else
-		    print_usage_util (stderr, program);
-		  return 1;
-		}
+		print_usage_util (stderr, program);
+	      return 1;
 	    }
 	  break;
 	case 'w':
