@@ -79,11 +79,11 @@ print_help (const char *program)
 	 stdout);
   fputs (_("  -e, --encrypted The passwords are in encrypted form\n"),
 	 stdout);
-  fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("      --help     Give this help list\n"), stdout);
   fputs (_("  -u, --usage    Give a short usage message\n"), stdout);
   fputs (_("  -v, --version  Print program version\n"), stdout);
-  fputs (_("Valid services for -r are: files, nis, nisplus, ldap\n"), stdout);
+  fputs (_("Valid services are: files, nis, nisplus, ldap\n"), stdout);
 }
 
 int
@@ -121,14 +121,14 @@ main (int argc, char *argv[])
         {"path",    required_argument, NULL, 'P' },
         {"crypt",   no_argument, NULL, 'c' },
         {"encrypt", no_argument, NULL, 'e' },
-        {"service", required_argument, NULL, 'r' },
+        {"service", required_argument, NULL, '\254' },
         {"version", no_argument, NULL, 'v' },
         {"usage",   no_argument, NULL, 'u' },
         {"help",    no_argument, NULL, '\255' },
         {NULL,      0,           NULL, '\0'}
       };
 
-      c = getopt_long (argc, argv, "D:P:c:er:vu",
+      c = getopt_long (argc, argv, "D:P:c:evu",
                        long_options, &option_index);
       if (c == (-1))
         break;
@@ -148,7 +148,7 @@ main (int argc, char *argv[])
 	case 'e':
 	  ++encrypted;
 	  break;
-        case 'r':
+        case '\254':
           if (use_service != NULL)
             {
               print_usage (stderr, program);
@@ -169,7 +169,7 @@ main (int argc, char *argv[])
 #endif
           else
             {
-              fprintf (stderr, _("Service \"%s\" not supported\n"), optarg);
+              fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
               print_usage (stderr, program);
               return E_BAD_ARG;
             }
@@ -206,7 +206,7 @@ main (int argc, char *argv[])
     }
   else if (argc > 1)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
