@@ -68,7 +68,7 @@ print_help (const char *program)
   fprintf (stdout, _("%s - change group password\n\n"), program);
 
   fputs (_("  -r             Remove the password for this group\n"), stdout);
-  fputs (_("  --service srv  Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("  -D binddn      Use dn \"binddn\" to bind to the LDAP directory\n"),
 	 stdout);
   fputs (_("  -P path        Search group file in \"path\"\n"),
@@ -195,7 +195,7 @@ main (int argc, char **argv)
   /* We need a group name.  */
   if (argc == 0)
     {
-      fprintf (stderr, _("%s: group argument missing.\n"), program);
+      fprintf (stderr, _("%s: Group argument missing.\n"), program);
       print_error (program);
       return E_USAGE;
     }
