@@ -81,11 +81,11 @@ print_help (const char *program)
 	 stdout);
   fputs (_("  -A user        Add the user to the group entry\n"), stdout);
   fputs (_("  -R user        Remove the user from the group entry\n"), stdout);
-  fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("      --help     Give this help list\n"), stdout);
   fputs (_("      --usage    Give a short usage message\n"), stdout);
   fputs (_("  -v, --version  Print program version\n"), stdout);
-  fputs (_("Valid services for -r are: files, ldap\n"), stdout);
+  fputs (_("Valid services are: files, ldap\n"), stdout);
 }
 
 static const char *program = "groupmod";
@@ -101,13 +101,13 @@ static struct option long_options[] = {
   {"password", required_argument, NULL, 'p'},
   {"add-user", required_argument, NULL, 'A'},
   {"remove-user", required_argument, NULL, 'R'},
-  {"service", required_argument, NULL, 'r'},
   {"version", no_argument, NULL, 'v'},
+  {"service", required_argument, NULL, '\253'},
   {"usage", no_argument, NULL, '\254'},
   {"help", no_argument, NULL, '\255'},
   {NULL, 0, NULL, '\0'}
 };
-static const char *short_options = "A:D:g:n:oP:p:R:r:v";
+static const char *short_options = "A:D:g:n:oP:p:R:v";
 
 static struct group *
 files_getgrnam (const char *name)
@@ -287,7 +287,7 @@ main (int argc, char **argv)
 	    }
 	  remove_user = locale_to_utf8 (optarg);
 	  break;
-	case 'r':
+	case '\253':
 	  if (use_service != NULL)
 	    {
 	      print_usage (stderr, program);
@@ -302,7 +302,7 @@ main (int argc, char **argv)
 #endif
 	  else
 	    {
-	      fprintf (stderr, _("Service \"%s\" not supported\n"), optarg);
+	      fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
 	      print_usage (stderr, program);
 	      return E_BAD_ARG;
 	    }
