@@ -231,13 +231,13 @@ loop_over_group_file (int quiet)
   input = fopen (inputname, "r");
   if (input == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), inputname);
+      fprintf (stderr, _("Can't open `%s': %m\n"), inputname);
       return E_NO_FILE;
     }
 
   if (fstat (fileno (input), &group_stat) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), inputname);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), inputname);
       fclose (input);
       return E_NO_FILE;
     }
@@ -263,7 +263,7 @@ loop_over_group_file (int quiet)
 #endif
   if (output_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+      fprintf (stderr, _("Can't create `%s': %m\n"),
 	       inputname);
       fclose (input);
       return E_NO_FILE;
@@ -271,7 +271,7 @@ loop_over_group_file (int quiet)
   if (fchmod (output_fd, group_stat.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("Cannot change mode for `%s': %s\n"),
+	       _("Cannot change permissions for `%s': %s\n"),
 	       outputname, strerror (errno));
       fclose (input);
       close (output_fd);
@@ -298,7 +298,7 @@ loop_over_group_file (int quiet)
   output = fdopen (output_fd, "w+");
   if (output == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), outputname);
+      fprintf (stderr, _("Can't open `%s': %m\n"), outputname);
       fclose (input);
       close (output_fd);
       unlink (outputname);
@@ -477,7 +477,8 @@ loop_over_group_file (int quiet)
       unlink (oldname);
       if (link (inputname, oldname) < 0)
 	fprintf (stderr,
-		 _("Warning: cannot create backup of group file: %m\n"));
+		 _("Warning: cannot create backup file `%s': %m\n"),
+		 oldname);
       rename (outputname, inputname);
     }
   else
@@ -603,13 +604,13 @@ sort_group_file (void)
 
   if ((oldgf = fopen (group_orig, "r")) == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), group_orig);
+      fprintf (stderr, _("Can't open `%s': %m\n"), group_orig);
       retval = -1;
       goto error_group;
     }
   if (fstat (fileno (oldgf), &group_stat) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), group_orig);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), group_orig);
       fclose (oldgf);
       retval = -1;
       goto error_group;
@@ -638,7 +639,7 @@ sort_group_file (void)
 #endif
   if (newgf_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+      fprintf (stderr, _("Can't create `%s': %m\n"),
 	       group_orig);
       fclose (oldgf);
       retval = -1;
@@ -647,7 +648,7 @@ sort_group_file (void)
   if (fchmod (newgf_fd, group_stat.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("Cannot change mode for `%s': %s\n"),
+	       _("Cannot change permissions for `%s': %s\n"),
 	       group_tmp, strerror (errno));
       fclose (oldgf);
       close (newgf_fd);
@@ -678,7 +679,7 @@ sort_group_file (void)
   newgf = fdopen (newgf_fd, "w+");
   if (newgf == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), group_tmp);
+      fprintf (stderr, _("Can't open `%s': %m\n"), group_tmp);
       fclose (oldgf);
       close (newgf_fd);
       unlink (group_tmp);
@@ -707,7 +708,8 @@ sort_group_file (void)
 	{
 	write_error_group:
 	  fprintf (stderr,
-		   _("Error while writing temporary group file: %m\n"));
+		   _("Error while writing `%s': %m\n"),
+                   group_tmp);
 	  fclose (oldgf);
 	  fclose (newgf);
 	  retval = -1;
@@ -718,7 +720,7 @@ sort_group_file (void)
   if (fclose (oldgf) != 0)
     {
       fprintf (stderr,
-	       _("Error while closing old group file: %m\n"));
+	       _("Error while closing `%s': %m\n"), group_orig);
       fclose (newgf);
       retval = -1;
       goto error_group;
@@ -726,14 +728,15 @@ sort_group_file (void)
   if (fclose (newgf) != 0)
     {
       fprintf (stderr,
-	       _("Error while closing temporary group file: %m\n"));
+	       _("Error while closing `%s': %m\n"), group_tmp);
       retval = -1;
       goto error_group;
     }
   unlink (group_old);
   if (link (group_orig, group_old) < 0)
     fprintf (stderr,
-	     _("Warning: cannot create backup of group file: %m\n"));
+	     _("Warning: cannot create backup file `%s': %m\n"),
+	     group_old);
   rename (group_tmp, group_orig);
  error_group:
   unlink (group_tmp);
@@ -805,13 +808,13 @@ main (int argc, char *argv[])
 
   if (argc > 0)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
   else if (readonly && sort)
     {
-      fprintf (stderr, _("%s: -s and -r are incompatibile\n"),
+      fprintf (stderr, _("%s: -s and -r are incompatibile.\n"),
 	       program);
       return E_USAGE;
     }
@@ -819,8 +822,7 @@ main (int argc, char *argv[])
   if (lock_database () != 0)
     {
       fprintf (stderr,
-	       _("%s: Cannot lock group files: already locked.\n"),
-	       program);
+	       _("Cannot lock group file: already locked.\n"));
       return E_PWDBUSY;
     }
 
