@@ -199,7 +199,7 @@ main (int argc, char *argv[])
 
   if (argc > 0)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
@@ -227,7 +227,7 @@ main (int argc, char *argv[])
 	    }
 	  else
 	    {
-	      fprintf (stderr, _("Can't stat %s: %m\n"), gshadow_path);
+	      fprintf (stderr, _("Can't stat `%s': %m\n"), gshadow_path);
 	      return E_FAILURE;
 	    }
 	}
