@@ -190,7 +190,7 @@ print_help (const char *program)
   fputs (_("  -n min         Set minimum field for \"account\"\n"), stdout);
   fputs (_("  -x max         Set maximum field for \"account\"\n"), stdout);
   fputs (_("  -w warn        Set warn field for \"account\"\n"), stdout);
-  fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("  -D binddn      Use dn \"binddn\" to bind to the LDAP directory\n"),
 	 stdout);
   fputs (_("  -P path        Search passwd and shadow file in \"path\"\n"),
@@ -199,7 +199,7 @@ print_help (const char *program)
   fputs (_("  --help         Give this help list\n"), stdout);
   fputs (_("  --usage        Give a short usage message\n"), stdout);
   fputs (_("  --version      Print program version\n"), stdout);
-  fputs (_("Valid services for -r are: files, nis, nisplus, ldap\n"), stdout);
+  fputs (_("Valid services are: files, nis, nisplus, ldap\n"), stdout);
 }
 
 static int
@@ -230,15 +230,15 @@ passwd_main (const char *program, int argc, char **argv)
 	{
 	  {"binddn", required_argument, NULL, 'D'},
 	  {"path", required_argument, NULL, 'P'},
-	  {"service", required_argument, NULL, 'r'},
 	  {"version", no_argument, NULL, '\255'},
 	  {"usage", no_argument, NULL, '\254'},
 	  {"help", no_argument, NULL, '\253'},
 	  {"stdin", no_argument, NULL, '\252'},
+	  {"service", required_argument, NULL, '\251'},
 	  {NULL, 0, NULL, '\0'}
 	};
 
-      c = getopt_long (argc, argv, "adD:hlqr:uSekn:x:i:w:P:", long_options,
+      c = getopt_long (argc, argv, "adD:hlquSekn:x:i:w:P:", long_options,
                        &option_index);
       if (c == EOF)
         break;
@@ -292,7 +292,7 @@ passwd_main (const char *program, int argc, char **argv)
         case 'q':
           silent = 1;  /* ok for users */
           break;
-        case 'r':
+        case '\251':
           if (use_service != NULL)
             {
               print_error (program);
@@ -310,7 +310,7 @@ passwd_main (const char *program, int argc, char **argv)
 	    use_service = "ldap";
           else
             {
-              fprintf (stderr, _("Service `%s' not supported\n"), optarg);
+              fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
               print_usage (stderr, program);
               return E_BAD_ARG;
             }
@@ -371,7 +371,7 @@ passwd_main (const char *program, int argc, char **argv)
      username */
   if (argc > 1|| (a_flag && S_flag && argc != 0))
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
