@@ -238,13 +238,13 @@ loop_over_passwd_file (int quiet)
   input = fopen (inputname, "r");
   if (input == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), inputname);
+      fprintf (stderr, _("Can't open `%s': %m\n"), inputname);
       return E_NO_FILE;
     }
 
   if (fstat (fileno (input), &passwd_stat) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), inputname);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), inputname);
       fclose (input);
       return E_NO_FILE;
     }
@@ -270,7 +270,7 @@ loop_over_passwd_file (int quiet)
 #endif
   if (output_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+      fprintf (stderr, _("Can't create `%s': %m\n"),
 	       inputname);
       fclose (input);
       return E_NO_FILE;
@@ -278,7 +278,7 @@ loop_over_passwd_file (int quiet)
   if (fchmod (output_fd, passwd_stat.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("Cannot change mode for `%s': %s\n"),
+	       _("Cannot change permissions for `%s': %s\n"),
 	       outputname, strerror (errno));
       fclose (input);
       close (output_fd);
@@ -305,7 +305,7 @@ loop_over_passwd_file (int quiet)
   output = fdopen (output_fd, "w+");
   if (output == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), outputname);
+      fprintf (stderr, _("Can't open `%s': %m\n"), outputname);
       fclose (input);
       close (output_fd);
       unlink (outputname);
@@ -471,7 +471,8 @@ loop_over_passwd_file (int quiet)
       unlink (oldname);
       if (link (inputname, oldname) < 0)
 	fprintf (stderr,
-		 _("Warning: cannot create backup of passwd file: %m\n"));
+		 _("Warning: cannot create backup file `%s': %m\n"),
+                 oldname);
       rename (outputname, inputname);
     }
   else
@@ -503,7 +504,7 @@ loop_over_shadow_file (int quiet)
   input = fopen (inputname, "r");
   if (input == NULL)
     {
-      /* fprintf (stderr, _("Can't open %s: %m\n"), inputname); */
+      /* fprintf (stderr, _("Can't open `%s': %m\n"), inputname); */
       return E_NO_FILE;
     }
 
@@ -512,7 +513,7 @@ loop_over_shadow_file (int quiet)
 
   if (fstat (fileno (input), &shadow_stat) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), inputname);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), inputname);
       fclose (input);
       return E_NO_FILE;
     }
@@ -538,7 +539,7 @@ loop_over_shadow_file (int quiet)
 #endif
   if (output_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+      fprintf (stderr, _("Can't create `%s': %m\n"),
 	       inputname);
       fclose (input);
       return E_NO_FILE;
@@ -546,7 +547,7 @@ loop_over_shadow_file (int quiet)
   if (fchmod (output_fd, shadow_stat.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("Cannot change mode for `%s': %s\n"),
+	       _("Cannot change permissions for `%s': %s\n"),
 	       outputname, strerror (errno));
       fclose (input);
       close (output_fd);
@@ -573,7 +574,7 @@ loop_over_shadow_file (int quiet)
   output = fdopen (output_fd, "w+");
   if (output == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), outputname);
+      fprintf (stderr, _("Can't open `%s': %m\n"), outputname);
       fclose (input);
       close (output_fd);
       unlink (outputname);
@@ -736,7 +737,8 @@ loop_over_shadow_file (int quiet)
       unlink (oldname);
       if (link (inputname, oldname) < 0)
 	fprintf (stderr,
-		 _("Warning: cannot create backup of shadow file: %m\n"));
+		 _("Warning: cannot create backup file `%s': %m\n"),
+                 oldname);
       rename (outputname, inputname);
     }
   else
@@ -862,13 +864,13 @@ sort_passwd_file (void)
 
   if ((oldgf = fopen (passwd_orig, "r")) == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), passwd_orig);
+      fprintf (stderr, _("Can't open `%s': %m\n"), passwd_orig);
       retval = -1;
       goto error_passwd;
     }
   if (fstat (fileno (oldgf), &passwd_stat) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), passwd_orig);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), passwd_orig);
       fclose (oldgf);
       retval = -1;
       goto error_passwd;
@@ -897,7 +899,7 @@ sort_passwd_file (void)
 #endif
   if (newgf_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s temp file: %m\n"),
+      fprintf (stderr, _("Can't create `%s': %m\n"),
 	       passwd_orig);
       fclose (oldgf);
       retval = -1;
@@ -906,7 +908,7 @@ sort_passwd_file (void)
   if (fchmod (newgf_fd, passwd_stat.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("Cannot change mode for `%s': %s\n"),
+	       _("Cannot change permissions for `%s': %s\n"),
 	       passwd_tmp, strerror (errno));
       fclose (oldgf);
       close (newgf_fd);
@@ -937,7 +939,7 @@ sort_passwd_file (void)
   newgf = fdopen (newgf_fd, "w+");
   if (newgf == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), passwd_tmp);
+      fprintf (stderr, _("Can't open `%s': %m\n"), passwd_tmp);
       fclose (oldgf);
       close (newgf_fd);
       unlink (passwd_tmp);
@@ -966,7 +968,8 @@ sort_passwd_file (void)
 	{
 	write_error_passwd:
 	  fprintf (stderr,
-		   _("Error while writing temporary passwd file: %m\n"));
+		   _("Error while writing `%s': %m\n"),
+                   passwd_tmp);
 	  fclose (oldgf);
 	  fclose (newgf);
 	  retval = -1;
@@ -977,7 +980,7 @@ sort_passwd_file (void)
   if (fclose (oldgf) != 0)
     {
       fprintf (stderr,
-	       _("Error while closing old passwd file: %m\n"));
+	       _("Error while closing `%s': %m\n"), passwd_orig);
       fclose (newgf);
       retval = -1;
       goto error_passwd;
@@ -985,14 +988,15 @@ sort_passwd_file (void)
   if (fclose (newgf) != 0)
     {
       fprintf (stderr,
-	       _("Error while closing temporary passwd file: %m\n"));
+	       _("Error while closing `%s': %m\n"), passwd_tmp);
       retval = -1;
       goto error_passwd;
     }
   unlink (passwd_old);
   if (link (passwd_orig, passwd_old) < 0)
     fprintf (stderr,
-	     _("Warning: cannot create backup of passwd file: %m\n"));
+	     _("Warning: cannot create backup file `%s': %m\n"),
+             passwd_old);
   rename (passwd_tmp, passwd_orig);
  error_passwd:
   unlink (passwd_tmp);
@@ -1064,13 +1068,13 @@ main (int argc, char *argv[])
 
   if (argc > 0)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
   else if (readonly && sort)
     {
-      fprintf (stderr, _("%s: -s and -r are incompatibile\n"),
+      fprintf (stderr, _("%s: -s and -r are incompatibile.\n"),
 	       program);
       return E_USAGE;
     }
@@ -1078,8 +1082,7 @@ main (int argc, char *argv[])
   if (lock_database () != 0)
     {
       fprintf (stderr,
-	       _("%s: Cannot lock password files: already locked.\n"),
-	       program);
+	       _("Cannot lock password file: already locked.\n"));
       return E_PWDBUSY;
     }
 
