@@ -1322,7 +1322,7 @@ main (int argc, char **argv)
 
   if (argc != 0)
     {
-      fprintf (stderr, _("%s: Too many arguments\n"), program);
+      fprintf (stderr, _("%s: Too many arguments.\n"), program);
       print_error (program);
       return E_USAGE;
     }
