@@ -509,7 +509,7 @@ write_defaults (const char *configfile, struct default_t *data)
 
   if (fstat (fileno (fp), &oldmode) < 0)
     {
-      fprintf (stderr, _("Can't stat %s: %m\n"), configfile);
+      fprintf (stderr, _("Can't stat `%s': %m\n"), configfile);
       fclose (fp);
       return -1;
     }
@@ -518,15 +518,15 @@ write_defaults (const char *configfile, struct default_t *data)
   new_fd = mkstemp (tmpname);
   if (new_fd == -1)
     {
-      fprintf (stderr, _("Can't create %s: %m\n"), tmpname);
+      fprintf (stderr, _("Can't create `%s': %m\n"), tmpname);
       fclose (fp);
       return -1;
     }
   if (fchmod (new_fd, oldmode.st_mode) < 0)
     {
       fprintf (stderr,
-	       _("%s: Cannot change mode for `%s': %s\n"),
-	       program, tmpname, strerror (errno));
+	       _("Cannot change permissions for `%s': %s\n"),
+	       tmpname, strerror (errno));
       fclose (fp);
       close (new_fd);
       unlink (tmpname);
@@ -535,8 +535,8 @@ write_defaults (const char *configfile, struct default_t *data)
   if (fchown (new_fd, oldmode.st_uid, oldmode.st_gid) < 0)
     {
       fprintf (stderr,
-	       _("%s: Cannot change owner/group for `%s': %s\n"),
-	       program, tmpname, strerror (errno));
+	       _("Cannot change owner/group for `%s': %s\n"),
+	       tmpname, strerror (errno));
       fclose (fp);
       close (new_fd);
       unlink (tmpname);
@@ -553,7 +553,7 @@ write_defaults (const char *configfile, struct default_t *data)
   new_fp = fdopen (new_fd, "w+");
   if (new_fp == NULL)
     {
-      fprintf (stderr, _("Can't open %s: %m\n"), configfile);
+      fprintf (stderr, _("Can't open `%s': %m\n"), configfile);
       fclose (fp);
       close (new_fd);
       unlink (tmpname);
@@ -950,7 +950,7 @@ create_mail_file (const char *user, uid_t uid, gid_t user_gid)
 
   if (stat (_PATH_MAILDIR, &st) == -1)
     {
-      fprintf (stderr, _("%s: Can't stat %s: %m\n"),
+      fprintf (stderr, _("%s: Can't stat `%s': %m\n"),
 	       program, _PATH_MAILDIR);
       free (fname);
       return E_MAIL_SPOOL;
@@ -999,8 +999,8 @@ create_mail_file (const char *user, uid_t uid, gid_t user_gid)
       if (fchown (fd, uid, gid) < 0)
 	{
 	  fprintf (stderr,
-		   _("%s: Cannot change owner/group for `%s': %s\n"),
-		   program, fname, strerror (errno));
+		   _("Cannot change owner/group for `%s': %s\n"),
+		   fname, strerror (errno));
 	  unlink (fname);
 	  free (fname);
 	  close (fd);
@@ -1009,8 +1009,8 @@ create_mail_file (const char *user, uid_t uid, gid_t user_gid)
       if (fchmod (fd, mode) < 0)
 	{
 	  fprintf (stderr,
-		   _("%s: Cannot change mode for `%s': %s\n"),
-		   program, fname, strerror (errno));
+		   _("Cannot change permissions for `%s': %s\n"),
+		   fname, strerror (errno));
 	  unlink (fname);
 	  free (fname);
 	  close (fd);
@@ -1074,14 +1074,14 @@ create_home_directory (const char *home, uid_t uid, gid_t gid,
       if (chown (home, uid, gid) < 0)
 	{
 	  fprintf (stderr,
-		   _("%s: Cannot change owner/group for `%s': %s\n"),
-		   program, home, strerror (errno));
+		   _("Cannot change owner/group for `%s': %s\n"),
+		   home, strerror (errno));
 	  retval = E_HOMEDIR;
 	}
       if (chmod (home, 0777 & ~getlogindefs_num ("UMASK", 077)) < 0)
 	{
-	  fprintf (stderr, _("%s: Cannot change mode for `%s': %s\n"),
-		   program, home, strerror (errno));
+	  fprintf (stderr, _("Cannot change permissions for `%s': %s\n"),
+		   home, strerror (errno));
 	  retval = E_HOMEDIR;
 	}
     }
