@@ -457,7 +457,7 @@ main (int argc, char **argv)
 #endif
           else
             {
-              fprintf (stderr, _("Service \"%s\" not supported\n"), optarg);
+              fprintf (stderr, _("Service `%s' not supported.\n"), optarg);
               print_usage (stderr, program);
               return E_BAD_ARG;
             }
