@@ -96,7 +96,7 @@ disabled\n"), stdout);
   fputs (_("  -s shell       Name of the user's login shell\n"), stdout);
   fputs (_("  -u uid         Change the userid to the given number\n"),
 	 stdout);
-  fputs (_("  -r service     Use nameservice 'service'\n"), stdout);
+  fputs (_("  --service srv  Use nameservice 'srv'\n"), stdout);
   fputs (_("  -L             Locks the password entry for \"user\"\n"),
 	 stdout);
   fputs (_("  -U             Try to unlock the password entry for \"user\"\n"),
@@ -104,7 +104,7 @@ disabled\n"), stdout);
   fputs (_("      --help     Give this help list\n"), stdout);
   fputs (_("      --usage    Give a short usage message\n"), stdout);
   fputs (_("  -v, --version  Print program version\n"), stdout);
-  fputs (_("Valid services for -r are: files, ldap\n"), stdout);
+  fputs (_("Valid services are: files, ldap\n"), stdout);
 }
 
 static const char *program = "usermod";
@@ -128,16 +128,16 @@ static struct option long_options[] = {
   {"non-unique", no_argument, NULL, 'o'},
   {"path", required_argument, NULL, 'P'},
   {"password", required_argument, NULL, 'p'},
-  {"service", required_argument, NULL, 'r'},
   {"shell", required_argument, NULL, 's'},
   {"uid", required_argument, NULL, 'u'},
   {"unlock", required_argument, NULL, 'U'},
   {"version", no_argument, NULL, 'v'},
+  {"service", required_argument, NULL, '\253'},
   {"usage", no_argument, NULL, '\254'},
   {"help", no_argument, NULL, '\255'},
   {NULL, 0, NULL, '\0'}
 };
-static const char *short_options = "A:c:D:d:e:f:G:g:l:LmoP:p:R:r:s:u:Uv";
+static const char *short_options = "A:c:D:d:e:f:G:g:l:LmoP:p:R:s:u:Uv";
 
 /* This function converts a comma seperated list of groups
    (a group can be a groupname or a group id) into a table
@@ -548,13 +548,13 @@ move_home_directory (const char *oldhome, const char *newhome)
 	{
 	  if (mkdir (newhome, st.st_mode & 0777))
 	    {
-	      fprintf (stderr, _("%s: Can't create %s.\n"),
-		       program, newhome);
+	      fprintf (stderr, _("Can't create `%s': %m\n"),
+		       newhome);
 	      return E_HOMEDIR;
 	    }
 	  if (chown (newhome, st.st_uid, st.st_gid))
 	    {
-	      fprintf (stderr, _("%s: Can't chown %s.\n"),
+	      fprintf (stderr, _("%s: Warning: chown on `%s' failed: %m\n"),
 		       program, newhome);
 	      rmdir (newhome);
 	      return E_HOMEDIR;
@@ -771,6 +771,7 @@ main (int argc, char **argv)
   int retval = E_SUCCESS;
   int lock_password = 0;
   int unlock_password = 0;
+  int a_flg = 0;
 
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -794,6 +795,9 @@ main (int argc, char **argv)
 	break;
       switch (c)
 	{
+	case 'a':
+	  a_flg = 1;
+	  break;
 	case 'c':
 	  if (strcspn (optarg, ":\n") != strlen (optarg))
 	    {
@@ -962,7 +966,7 @@ main (int argc, char **argv)
 	    }
 	  unlock_password = 1;
 	  break;
-	case 'r':
+	case '\253':
 	  if (use_service != NULL)
 	    {
 	      print_usage (stderr, program);
@@ -1000,6 +1004,17 @@ main (int argc, char **argv)
   argc -= optind;
   argv += optind;
 
+  if (a_flg) /* -a -G is identical to -A */
+    {
+      if (add_groups_arg)
+	{
+	  print_usage (stderr, program);
+	  return E_BAD_ARG;
+	}
+      add_groups_arg = new_groups_arg;
+      new_groups_arg = NULL;
+    }
+
   if (argc > 1)
     {
       fprintf (stderr, _("%s: Too many arguments.\n"), program);
